@@ -16,7 +16,7 @@ test_that("DNA can be simulated", {
   expect_is(stat$dna[[2]], "matrix")
 
   temp_files_before <- list.files(tempdir(), pattern = "^coala-[0-9]+-")
-  expect_error(simulate(model + sumstat_sfs() + feat_outgroup(2)))
+  expect_error(simulate(model + feat_unphased(1)))
   expect_error(simulate(model + locus_trio()))
 
   # Remove tempfiles that may remain because of error exit
